==> captchaimageclick_7.59_ru.zip: captchaimageclick/CaptchaImageClick_TikTok_interface.js <==
<div class="container-fluid">
<%= _.template($('#input_constructor').html())({id:"arkywdqv", description:tr("Captcha Selector"), default_selector:"string", disable_expression:true, disable_int:true, variants:[">CSS> div[class*='captcha'][class*='container']<br/><span style='color:gray;font-size:small'>Cтандартный селектор от всех видов тикток капчи. Этот селектор можно использовать для проверки видимости капчи.</span>"], value_string:">CSS> div[class*='captcha'][class*='container']", help:{description:tr("Standard selector from all types of captcha tictics. This selector can be used to check if the captcha is visible, and then run an action with the module. The order of action is as follows: 1. Check the existence of the selector 2. Run the module to solve the Tiktok captcha.")}}) %>
<%= _.template($('#input_constructor').html())({id:"arahvjxt", description:tr("Solve Method"), default_selector: "string", variants: ["Cap.Guru [Russian Server]", "Cap.Guru [German Server]", "Cap.Guru [Finland Server]", "Cap.Guru [Asian Server]"], disable_expression:true, disable_int:true, value_string: "", help: {description: tr("In this string you need to specify which of the cap.guru servers you want to send your captcha to. Please note, that captcha solving requests are not sent through a proxy, but directly from the Internet connection of your PC or server. If you observe problems with access to one of the servers, then change the solution server in the settings. It is recommended to use the RU server if you solve captcha on a server or PC from Russia, if your server is located outside of Russia, then it is recommended to use a server in Germany for solving.")} }) %>
<%= _.template($('#input_constructor').html())({id:"lktihatm", description:tr("Secret API Key"), default_selector: "string", disable_expression: true, disable_int: true, value_string: "", help: {description: tr("In this field, you must specify the secret API key for your solution method, this key must be purchased at the recognition service https://cap.guru. Example: 1ceb81e1cbd343b136bcc3975f914dd1")} }) %>
<div style="margin-left: 20px;">
<input type="checkbox" id="AdvancedCheck" onchange="$('#Advanced').toggle()" />
<label for="AdvancedCheck" class="tr" >Advanced settings.</label>
</div>
<span id="Advanced" style="display:none">
<%= _.template($('#input_constructor').html())({id:"yedcnloz", description:tr("Click speed"), default_selector: "string", variants: ["Slow","Normal","Fast","Very Fast","Extreme"], disable_expression:true, disable_int:true, value_string: "Slow", help: {description: tr("This setting changes the behavior of mouse movement speed in the module and captcha click speed, by default the default speed is used, which is set globally in BAS."), examples: [{ code: "Slow", description: tr("standard mouse movement and click speed")},{ code: "Fast", "description": tr("accelerated x3 mouse movement and click speed")},{ code: "Extreme", "description": tr("instant x5 mouse movement and click speed")}]}}) %>
<%= _.template($('#input_constructor').html())({id:"hqvqbpch", description:tr("Attempts to solve"), default_selector: "int", disable_string: true, value_number: 10, min_number:1, max_number:999999, help: {description: tr("This parameter determines the maximum number of attempts to solve the captcha by clicking on the image or dragging the slider at the round Tiktok captcha. Recommended value is 10.")} }) %>
<%= _.template($('#input_constructor').html())({id:"rndcqiqx", description:tr("Enable debug mode?"), default_selector: "expression", variants: [true, false], disable_int:true, disable_string:true, value_string: false, help: {description: tr("This setting is needed to enable detailed logging of all module actions. It is primarily intended for the module developer and will most likely be unnecessary for you. However, if issues arise with the module, enable this mode to generate a detailed bug report."),examples: [{ code: "true", description: tr("enable debug mode")},{ code: "false", "description": tr("disable debug mode")}]}}) %>
</span>
</div>
<div class="tooltipinternal">
<div class="tr tooltip-paragraph-first-fold">Решить <span style="color: #000000;">TikTok</span> каптчу любого типа <code>(2 objects, Puzzle, Сircular)</code>, используя метод кликов по изображению или метод перетягивания ползунка в заданное направление.</div>
<div class="tr tooltip-paragraph-fold"><code>Please note!</code> In order to solve this capcha, you need to resolve the cache in the current thread, you can do this here: the 'Network' module - the 'Allow cache' action. You must create 5 such actions with the following mask - <code>*ibyteimg.com*</code>, <code>*ibytedtos.com*</code>, <code>*captcha*</code>, <code>*captcha*tiktokcdn*</code> and *blob*tiktok*.</div>
<div class="tr tooltip-paragraph-fold">You need to place these actions at the beginning of the template, for example, after loading the page with the site where you collected the captcha.</div>
<div class="tr tooltip-paragraph-fold">This action performs automatic clicks on image numbers or coordinates, takes a screenshot of the image and sends it to the service or program you specified by the capch solution. There is no need to perform any additional actions.</div>
<div class="tr tooltip-paragraph-fold">This solution method is convenient in that you do not need to search for how to call 'callback' on the site, study complex JavaScripts in order to successfully pass the captcha solution.</div>
<div class="tr tooltip-paragraph-fold">This means that you do not need to constantly disable or enable this module in your scripts for fear of sanctions from the site. For example, when you warm up a profile, this action will not create any new properties of the window object or even replace the current ones.</div>
<div class="tr tooltip-paragraph-last-fold">Pay attention! This action does not create any 'dangerous code' inside the browser and does not break other types of captcha on sites, as the actions to solve captcha from the context menu do.</div>
</div>
<%= _.template($('#back').html())({action:"executeandadd", visible:true}) %>

==> captchaimageclick_7.81_ru.zip: captchaimageclick/CaptchaImageClick_TikTok_interface.js <==
<div class="container-fluid">
<%= _.template($('#input_constructor').html())({id:"arkywdqv", description:tr("Captcha Selector"), default_selector:"string", disable_expression:true, disable_int:true, variants:[">CSS> div[class*='captcha'][class*='container']<br/><span style='color:gray;font-size:small'>Cтандартный селектор от всех видов тикток капчи. Этот селектор можно использовать для проверки видимости капчи.</span>"], value_string:">CSS> div[class*='captcha'][class*='container']", help:{description:tr("Standard selector from all types of captcha tictics. This selector can be used to check if the captcha is visible, and then run an action with the module. The order of action is as follows: 1. Check the existence of the selector 2. Run the module to solve the Tiktok captcha.")}}) %>
<%= _.template($('#input_constructor').html())({id:"arahvjxt", description:tr("Solve Method"), default_selector: "string", variants: ["Cap.Guru [Russian Server]", "Cap.Guru [German Server]", "Cap.Guru [Finland Server]", "Cap.Guru [Asian Server]"], disable_expression:true, disable_int:true, value_string: "", help: {description: tr("In this string you need to specify which of the cap.guru servers you want to send your captcha to. Please note, that captcha solving requests are not sent through a proxy, but directly from the Internet connection of your PC or server. If you observe problems with access to one of the servers, then change the solution server in the settings. It is recommended to use the RU server if you solve captcha on a server or PC from Russia, if your server is located outside of Russia, then it is recommended to use a server in Germany for solving.")} }) %>
<%= _.template($('#input_constructor').html())({id:"lktihatm", description:tr("Secret API Key"), default_selector: "string", disable_expression: true, disable_int: true, value_string: "", help: {description: tr("In this field, you must specify the secret API key for your solution method, this key must be purchased at the recognition service https://cap.guru. Example: 1ceb81e1cbd343b136bcc3975f914dd1")} }) %>
<div style="margin-left: 20px;">
<input type="checkbox" id="AdvancedCheck" onchange="$('#Advanced').toggle()" />
<label for="AdvancedCheck" class="tr" >Advanced settings.</label>
</div>
<span id="Advanced" style="display:none">
<%= _.template($('#input_constructor').html())({id:"yedcnloz", description:tr("Click speed"),default_selector:"string",variants:["Slow","Normal","Fast","Very Fast","Extreme","Custom"],disable_expression:true,disable_int:true,value_string:"Slow",help:{description:tr("This setting changes the behavior of mouse movement speed in the module and captcha click speed, by default the default speed is used, which is set globally in BAS."),examples:[{code:"Slow",description:tr("standard mouse movement and click speed")},{code:"Fast",description:tr("accelerated x3 mouse movement and click speed")},{code:"Extreme",description:tr("instant x5 mouse movement and click speed")},{code:"Custom:100:3:2.5",description:tr("custom speed setting: SPEED:GRAVITY:DEVIATION, e.g. Custom:100:3:2.5")} ]}}) %>
<%= _.template($('#input_constructor').html())({id:"hqvqbpch", description:tr("Attempts to solve"), default_selector: "int", disable_string: true, value_number: 10, min_number:1, max_number:999999, help: {description: tr("This parameter determines the maximum number of attempts to solve the captcha by clicking on the image or dragging the slider at the round Tiktok captcha. Recommended value is 10.")} }) %>
<%= _.template($('#input_constructor').html())({id:"rndcqiqx", description:tr("Enable debug mode?"), default_selector: "expression", variants: [true, false], disable_int:true, disable_string:true, value_string: false, help: {description: tr("This setting is needed to enable detailed logging of all module actions. It is primarily intended for the module developer and will most likely be unnecessary for you. However, if issues arise with the module, enable this mode to generate a detailed bug report."),examples: [{ code: "true", description: tr("enable debug mode")},{ code: "false", "description": tr("disable debug mode")}]}}) %>
<%= _.template($('#input_constructor').html())({id:"btqeslmfj", description:tr("Disable warnings?"), default_selector: "expression", variants: [true, false], disable_int:true, disable_string:true, value_string: false, help: {description: tr("This setting controls the version validity check before the module starts. When the module is launched, it checks whether the installed version is up to date. The result of the check (whether the version is current or not) is written to the log file. This behavior can be disabled if needed."),examples: [{ code: "true", description: tr("disable warnings")},{ code: "false", "description": tr("enable warnings")}]}}) %>
</span>
</div>
<div class="tooltipinternal">
<div class="tr tooltip-paragraph-first-fold">Решить <span style="color: #000000;">TikTok</span> каптчу любого типа <code>(2 objects, Puzzle, Сircular)</code>, используя метод кликов по изображению или метод перетягивания ползунка в заданное направление.</div>
<div class="tr tooltip-paragraph-fold"><code>Important note: to solve this type of captcha, you need to create an action that enables caching with the parameter set to true for your captcha.</code></div>
<div class="tr tooltip-paragraph-fold">This action performs automatic clicks on image numbers or coordinates, takes a screenshot of the image and sends it to the service or program you specified by the capch solution. There is no need to perform any additional actions.</div>
<div class="tr tooltip-paragraph-fold">This solution method is convenient in that you do not need to search for how to call 'callback' on the site, study complex JavaScripts in order to successfully pass the captcha solution.</div>
<div class="tr tooltip-paragraph-fold">This means that you do not need to constantly disable or enable this module in your scripts for fear of sanctions from the site. For example, when you warm up a profile, this action will not create any new properties of the window object or even replace the current ones.</div>
<div class="tr tooltip-paragraph-last-fold">Pay attention! This action does not create any 'dangerous code' inside the browser and does not break other types of captcha on sites, as the actions to solve captcha from the context menu do.</div>
</div>
<%= _.template($('#back').html())({action:"executeandadd", visible:true}) %>
